# libpythonbruno

Módulo para exemplificar construção de projetos Python no curso Pytools

Nesse curso é ensinado como contribuir com projetos de código aberto\

Link para o curso [Python Pro](https://www.python.pro.br) 

[![Build Status](https://app.travis-ci.com/brunoccalmeida/libpythonbruno.svg?branch=master)](https://app.travis-ci.com/brunoccalmeida/libpythonbruno)

[![Updates](https://pyup.io/repos/github/brunoccalmeida/libpythonbruno/shield.svg)](https://pyup.io/repos/github/brunoccalmeida/libpythonbruno/)

[![Python 3](https://pyup.io/repos/github/brunoccalmeida/libpythonbruno/python-3-shield.svg)](https://pyup.io/repos/github/brunoccalmeida/libpythonbruno/)

Suportada versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade do código:

```console
flake8
```

Tópicos a serem abordados:

1.Git
2. Virtualevn
3. Pip
